@@ -11,7 +11,7 @@ __version__ = '0.0.1'
 __author__ = 'Marco Lovato'
 __author_username__ = 'lovato'
 __author_email__ = 'maglovato@gmail.com'
-__description__ = 'A simple python boilerplate - and multi template! - to start your python work.'
+__description__ = 'A command-line tool to create projects from templates, to start your python work.'
 
 log_filename = os.path.join(tempfile.gettempdir(), 'machete-' + getpass.getuser() + '.log')
 
